shareUri function
Start share intent for the given uri.
To share a file, use Uri.parse passing the file absolute path as argument.
Note that this method can only share files that your app has permission over, either by being in your app domain (e.g file from your app cache) or that is granted by openDocumentTree.
Implementation
@willbemovedsoon
Future<void> shareUri(
Uri uri, {
String? type,
}) {
final Map<String, dynamic> args = <String, dynamic>{
'uri': '$uri',
'type': type,
};
return kDocumentFileHelperChannel.invokeMethod<void>('shareUri', args);
}